{%- if pagename != "search" %}
<div class="panel panel-default">
  <div class="panel-heading">
    <h3 class="panel-title">Search</h3>
  </div>
  <div class="panel-body">
    <form class="form-inline" action="{{ pathto('search') }}" method="get" role="form">
      <div class="input-group">
        <input name="q" type="text" class="form-control">
        <span class="input-group-btn">
          <button class="btn btn-default" type="button">Go</button>
        </span>
      </div>
      <input type="hidden" name="check_keywords" value="yes" />
      <input type="hidden" name="area" value="default" />
    </form>
  </div>
</div>
{%- endif %}
